// -*- C++ -*-
/*!
 * @file  RTC_String_to_Pose3D.cpp
 * @brief String_to_Pose3D
 * @date $Date$
 *
 * $Id$
 */

#include "RTC_String_to_Pose3D.h"

#include <string.h>
using namespace std;
// Module specification
// <rtc-template block="module_spec">
static const char* rtc_string_to_pose3d_spec[] =
  {
    "implementation_id", "RTC_String_to_Pose3D",
    "type_name",         "RTC_String_to_Pose3D",
    "description",       "String_to_Pose3D",
    "version",           "1.0.0",
    "vendor",            "AIZUK",
    "category",          "TEST",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
RTC_String_to_Pose3D::RTC_String_to_Pose3D(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_StringIn("String", m_String),
    m_Pose3DOut("Pose3D", m_Pose3D)

    // </rtc-template>
{
}

/*!
 * @brief destructor
 */
RTC_String_to_Pose3D::~RTC_String_to_Pose3D()
{
}



RTC::ReturnCode_t RTC_String_to_Pose3D::onInitialize()
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  addInPort("String", m_StringIn);
  
  // Set OutPort buffer
  addOutPort("Pose3D", m_Pose3DOut);
  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  
  // Set CORBA Service Ports
  
  // </rtc-template>

  // <rtc-template block="bind_config">
  // </rtc-template>
  
  return RTC::RTC_OK;
}


RTC::ReturnCode_t RTC_String_to_Pose3D::onFinalize()
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t RTC_String_to_Pose3D::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t RTC_String_to_Pose3D::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t RTC_String_to_Pose3D::onActivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t RTC_String_to_Pose3D::onDeactivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t RTC_String_to_Pose3D::onExecute(RTC::UniqueId ec_id)
{
  if( m_StringIn.isNew() ){
  	char rev[256];
  	std::string s;
  	m_StringIn.read();
  	s=m_String.data;
  	
  	strncpy(rev, s.c_str(), 256);
	
	//printf("%s\n\r",rev);
	float x,y,z;
	float roll,pitch,yaw;
	sscanf(rev,"%f:%f:%f:%f:%f:%f\n",&x,&y,&z,&roll,&pitch,&yaw);
	printf("%f:%f:%f:%f:%f:%f\n",x,y,z,roll,pitch,yaw);
	
	m_Pose3D.data.position.x=x;
	m_Pose3D.data.position.y=y;
	m_Pose3D.data.position.z=z;
	m_Pose3D.data.orientation.y=yaw;
	m_Pose3D.data.orientation.p=pitch;
	m_Pose3D.data.orientation.r=roll;
	m_Pose3DOut.write();
//	Logout_S << rev << endl;
  }
  
  return RTC::RTC_OK;
}


RTC::ReturnCode_t RTC_String_to_Pose3D::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t RTC_String_to_Pose3D::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t RTC_String_to_Pose3D::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t RTC_String_to_Pose3D::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t RTC_String_to_Pose3D::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}



extern "C"
{
 
  void RTC_String_to_Pose3DInit(RTC::Manager* manager)
  {
    coil::Properties profile(rtc_string_to_pose3d_spec);
    manager->registerFactory(profile,
                             RTC::Create<RTC_String_to_Pose3D>,
                             RTC::Delete<RTC_String_to_Pose3D>);
  }
  
};


